@@ -11,7 +11,6 @@ Date modified: -
 """
 
 import argparse
-import sys
 from imessage_reader import info
 from imessage_reader import fetch_data
 
@@ -28,8 +27,7 @@ def get_parser():
                         help='Show the current version.',
                         action='store_true')
 
-    args = parser.parse_args()
-    return args
+    return parser
 
 
 def evaluate(args):
@@ -51,8 +49,9 @@ def main():
     Entrypoint to the command-line interface (CLI).
     """
 
-    args = get_parser()
-    sys.stdout.write(str(evaluate(args)))
+    parser = get_parser()
+    args = parser.parse_args()
+    evaluate(args)
 
 
 if __name__ == '__main__':
