@@ -6,24 +6,17 @@ Fetch data, print data and export data to excel.
 Python 3.8+
 Author: niftycode
 Date created: October 8th, 2020
-Date modified: October 19th, 2020
+Date modified: October 27th, 2020
 """
 
 
+import sys
 from dataclasses import dataclass
 from os.path import expanduser
 from imessage_reader import common
 from imessage_reader import write_excel
 
 
-# The path to the iMessage database
-DB_PATH = expanduser("~") + '/Library/Messages/chat.db'
-
-# The SQL command
-SQL_CMD = "SELECT message.text, handle.id, handle.service " \
-              "FROM message JOIN handle on message.handle_id=handle.ROWID"
-
-
 @dataclass
 class MessageData:
     """
@@ -32,6 +25,7 @@ class MessageData:
     """
     user_id: str
     text: str
+    date: int
     service: str
 
     def __str__(self):
@@ -40,6 +34,7 @@ class MessageData:
         """
         return f"user id: {self.user_id}:\n" \
                f"message: {self.text}\n" \
+               f"date: {self.date}\n" \
                f"service: {self.service}\n"
 
 
@@ -48,21 +43,38 @@ class FetchData:
     """
     This class contains the methods for fetch, print and export the messages.
     """
-    def __init__(self, db_path=None, sql_cmd=None):
-        self.db_path = DB_PATH
-        self.sql_cmd = SQL_CMD
+
+    def __init__(self, system=None):
+        if system is None:
+            self.operating_system = common.get_platform()
+
+    def check_system(self):
+        if self.operating_system != 'MAC':
+            sys.exit("Your operating system is not supported yet!")
+
+    # The path to the iMessage database
+    DB_PATH = expanduser("~") + '/Library/Messages/chat.db'
+
+    # The SQL command
+    SQL_CMD = "SELECT " \
+              "text, " \
+              "datetime((date / 1000000000) + 978307200, 'unixepoch', 'localtime')," \
+              "handle.id, " \
+              "handle.service " \
+              "FROM message " \
+              "JOIN handle on message.handle_id=handle.ROWID"
 
     def read_database(self) -> list:
         """
         Fetch data from the database and store the data in a list.
-        :return: List containing the user id and the message
+        :return: List containing the user id, the message and the service
         """
 
-        rval = common.fetch_db_data(self.db_path, self.sql_cmd)
+        rval = common.fetch_db_data(self.DB_PATH, self.SQL_CMD)
 
         data = []
         for row in rval:
-            data.append(MessageData(row[1], row[0], row[2]))
+            data.append(MessageData(row[2], row[0], row[1], row[3]))
         return data
 
     def show_user_txt(self, export: bool):
@@ -72,6 +84,10 @@ class FetchData:
         :param export: Determine whether to export data
         """
 
+        # Check the running operating system
+        self.check_system()
+
+        # Read chat.db
         fetched_data = self.read_database()
 
         # CLI output
@@ -86,9 +102,10 @@ class FetchData:
         """
         Export data (write Excel file)
         This method is for CLI usage.
-        :param data: imessage objects containing user id and text
+        :param data: imessage objects containing user id, message and service
         """
-        ew = write_excel.ExelWriter(data)
+        file_path = expanduser("~") + '/Desktop/'
+        ew = write_excel.ExelWriter(data, file_path)
         ew.write_data()
 
     def get_messages(self) -> list:
@@ -100,13 +117,15 @@ class FetchData:
 
         users = []
         messages = []
+        dates = []
         service = []
 
         for data in fetched_data:
             users.append(data.user_id)
             messages.append(data.text)
+            dates.append(data.date)
             service.append(data.service)
 
-        data = list(zip(users, messages, service))
+        data = list(zip(users, messages, dates, service))
 
         return data
